@@ -3,7 +3,7 @@ package Sah::Schema::color::ansi16;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [str => {
     summary => 'ANSI-16 color, either a number from 0-15 or color names like "black", "bold red", etc',
@@ -13,7 +13,7 @@ our $schema = [str => {
         {value=> 0, valid=>1},
         {value=>15, valid=>1},
         {value=>16, valid=>0},
-        {value=>'black'  , valid=>1, res=>'black'},
+        {value=>'black'  , valid=>1, validated_value=>'black'},
         {value=>'foo'    , valid=>0},
     ],
 }, {}];
@@ -33,7 +33,7 @@ Sah::Schema::color::ansi16 - ANSI-16 color, either a number from 0-15 or color n
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::color::ansi16 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
+This document describes version 0.011 of Sah::Schema::color::ansi16 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes "black"
+ undef  # valid
 
  undef  # INVALID
 
