@@ -3,7 +3,7 @@ package Sah::Schema::color::rgb24;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Color'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
@@ -11,10 +11,10 @@ our $schema = [str => {
     'x.completion' => ['colorname'],
     'x.perl.coerce_rules' => ['From_str::rgb24_from_colorname_X_or_code'],
     examples => [
-        {value=>'000000' , valid=>1, res=>'000000'},
-        {value=>'black'  , valid=>1, res=>'000000'},
-        {value=>'FFffcc' , valid=>1, res=>'ffffcc'},
-        {value=>'#FFffcc', valid=>1, res=>'ffffcc'},
+        {value=>'000000' , valid=>1, validated_value=>'000000'},
+        {value=>'black'  , valid=>1, validated_value=>'000000'},
+        {value=>'FFffcc' , valid=>1, validated_value=>'ffffcc'},
+        {value=>'#FFffcc', valid=>1, validated_value=>'ffffcc'},
         {value=>'foo'    , valid=>0},
     ],
 }, {}];
@@ -34,7 +34,7 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
+This document describes version 0.011 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -70,13 +70,13 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid, becomes "000000"
+ undef  # valid
 
- undef  # valid, becomes "000000"
+ undef  # valid
 
- undef  # valid, becomes "ffffcc"
+ undef  # valid
 
- undef  # valid, becomes "ffffcc"
+ undef  # valid
 
  undef  # INVALID
 
